@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-hamlet
 version: 0.4.0.11
-id: xml-hamlet-0.4.0.11-0c1bb389bc2a3ce0045aa2368d4cab75
-key: xmlha_B1duazEMYhR4zflm5n24N0
+id: xml-hamlet-0.4.0.11-bcb43e99f97583f59903928997a32e4a
+key: xmlha_BoP3TWZRnnL4iPyCwtxWdT
 license: BSD3
 maintainer: michael@snoyman.com
 homepage: http://www.yesodweb.com/
@@ -20,15 +20,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-hamlet-0.4.0.11
-hs-libraries: HSxml-hamlet-0.4.0.11-B1duazEMYhR4zflm5n24N0
+hs-libraries: HSxml-hamlet-0.4.0.11-BoP3TWZRnnL4iPyCwtxWdT
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
-    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
+    shakespeare-2.0.8.2-b321569ec5295e19a9b3f8b5ef85b2ad
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
-    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
+    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
 haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
 haddock-html: /usr/share/doc/haskell-xml-hamlet/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
